# OwnTwin CLI

OwnTwin CLI is a toolchain for OwnTwin, a user-driven digital twin framework.

## Installation

```
pip install owntwin
```

## Usage

See the [documentation](https://beta.owntwin.com/docs/getting-started) for details.

```
owntwin init
owntwin add-terrain
owntwin add [module names...]
owntwin export
```

```
owntwin view
```
